pub struct ParseError {
pub column: usize,
pub message: String,
pub source: Option<String>,
pub suggestion: Option<String>,
}Fields
column: usizemessage: Stringsource: Option<String>The original query source (trimmed), used to show surrounding context.
suggestion: Option<String>An optional suggestion to help the user fix the error.
Implementations
Sourceimpl ParseError
impl ParseError
pub fn new(column: usize, message: impl Into<String>) -> Self
pub fn with_source(self, source: String) -> Self
Sourcepub fn with_suggestion(self, suggestion: impl Into<String>) -> Self
pub fn with_suggestion(self, suggestion: impl Into<String>) -> Self
Set a suggestion for how to fix the error.
Sourcepub fn format_color(&self) -> String
pub fn format_color(&self) -> String
Return a fully ANSI-coloured error string suitable for terminal display.